@@ -25,9 +25,3 @@ def convert(path):
         with open(html_dir / image.get_name(), 'wb') as f:
             f.write(image.get_content())
     print(f'"{html_dir}" created.')
-
-def example():
-    convert('data/epub-example.epub')
-
-if __name__ == '__main__':
-    example()
